xbuddy: Fix inclusion language

BUG=b:173219947
TEST=CQ passes

Change-Id: I30afb0c83981d7629fe9da74fbc7acfa5dc67216
Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/chromite/+/2538201
Commit-Queue: Amin Hassani <ahassani@chromium.org>
Commit-Queue: Jae Hoon Kim <kimjae@chromium.org>
Tested-by: Amin Hassani <ahassani@chromium.org>
Auto-Submit: Amin Hassani <ahassani@chromium.org>
Reviewed-by: Jae Hoon Kim <kimjae@chromium.org>
diff --git a/lib/xbuddy/android_build.py b/lib/xbuddy/android_build.py
index eb005c1..9d40e4f 100644
--- a/lib/xbuddy/android_build.py
+++ b/lib/xbuddy/android_build.py
@@ -171,7 +171,7 @@
 
   @classmethod
   @retry.retry(Exception, timeout_min=QUERY_TIMEOUT_MINS,
-               blacklist=[AndroidBuildFetchError])
+               denylist=[AndroidBuildFetchError])
   def GetLatestBuildID(cls, target, branch):
     """Get the latest build ID for the given target and branch.
 
diff --git a/lib/xbuddy/retry.py b/lib/xbuddy/retry.py
index a28fb8d..4889f8f 100644
--- a/lib/xbuddy/retry.py
+++ b/lib/xbuddy/retry.py
@@ -24,12 +24,12 @@
   return cherrypy_log_util.LogWithTag('RETRY', message, *args)
 
 
-def retry(ExceptionToCheck, timeout_min=1.0, delay_sec=3, blacklist=None):
+def retry(ExceptionToCheck, timeout_min=1.0, delay_sec=3, denylist=None):
   """Retry calling the decorated function using a delay with jitter.
 
   Will raise RPC ValidationError exceptions from the decorated
   function without retrying; a malformed RPC isn't going to
   magically become good. Will raise exceptions in blacklist as well.
 
   original from:
     http://www.saltycrane.com/blog/2009/11/trying-out-retry-decorator-python/
@@ -41,7 +41,7 @@
     delay_sec: pre-jittered delay between retries in seconds.  Actual delays
                will be centered around this value, ranging up to 50% off this
                midpoint.
     blacklist: a list of exceptions that will be raised without retrying
   """
   def deco_retry(func):
     random.seed()
@@ -56,7 +56,7 @@
       # Used to cache exception to be raised later.
       exc_info = None
       delayed_enabled = False
-      exception_tuple = () if blacklist is None else tuple(blacklist)
+      exception_tuple = () if denylist is None else tuple(denylist)
       start_time = time.time()
       remaining_time = timeout_min * 60
@@ -24,12 +24,12 @@
   Will raise RPC ValidationError exceptions from the decorated
   function without retrying; a malformed RPC isn't going to
-  magically become good. Will raise exceptions in blacklist as well.
+  magically become good. Will raise exceptions in denylist as well.
 
   original from:
@@ -41,7 +41,7 @@
                will be centered around this value, ranging up to 50% off this
                midpoint.
-    blacklist: a list of exceptions that will be raised without retrying
+    denylist: a list of exceptions that will be raised without retrying
   """
   def deco_retry(func):